import React, { Component } from 'react';
import { Redirect, Switch, RouteComponentProps } from 'react-router-dom'

import { Tabs, Tab } from '@material-ui/core';

import { PROJECT_PATH } from '../api';
import { MenuAppBar } from '../components';
import { AuthenticatedRoute } from '../authentication';

import GeneralInformation from './GeneralInformation';
import SettingsController from "./SettingsController";
import HeatingInformation from "./HeatingInformation";

class PumpControl extends Component<RouteComponentProps> {

  handleTabChange = (event: React.ChangeEvent<{}>, path: string) => {
    this.props.history.push(path);
  };

  render() {
    return (
      <MenuAppBar sectionTitle="Wasserpumpensteuerung">
        <Tabs value={this.props.match.url} onChange={this.handleTabChange} variant="fullWidth">
          <Tab value={`/${PROJECT_PATH}/pumpe/information`} label="Information" />
            <Tab value={`/${PROJECT_PATH}/pumpe/heizung`} label="Heizung" />
          <Tab value={`/${PROJECT_PATH}/pumpe/settings`} label="Einstellungen" />
        </Tabs>
        <Switch>
          <AuthenticatedRoute exact path={`/${PROJECT_PATH}/pumpe/information`} component={GeneralInformation} />
            <AuthenticatedRoute exact path={`/${PROJECT_PATH}/pumpe/heizung`} component={HeatingInformation} />
          <AuthenticatedRoute exact path={`/${PROJECT_PATH}/pumpe/settings`} component={SettingsController} />
          <Redirect to={`/${PROJECT_PATH}/pumpe/information`} />
        </Switch>
      </MenuAppBar>
    )
  }

}

export default PumpControl;
